mailr3589 - /1.3/test_suite/unit_tests/spin_testing_base.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on November 18, 2007 - 22:13:
Author: bugman
Date: Sun Nov 18 22:13:18 2007
New Revision: 3589

URL: http://svn.gna.org/viewcvs/relax?rev=3589&view=rev
Log:
Preparation of the prompt.spin and generic_fns.spin base class.


Modified:
    1.3/test_suite/unit_tests/spin_testing_base.py

Modified: 1.3/test_suite/unit_tests/spin_testing_base.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/spin_testing_base.py?rev=3589&r1=3588&r2=3589&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/spin_testing_base.py (original)
+++ 1.3/test_suite/unit_tests/spin_testing_base.py Sun Nov 18 22:13:18 2007
@@ -20,18 +20,17 @@
 #                                                                            
 #
 
###############################################################################
 
-# Python module imports.
-from unittest import TestCase
-
 # relax module imports.
 from data import Data as relax_data_store
-from generic_fns import spin
 from relax_errors import RelaxError, RelaxNoPipeError
 
 
 
-class Test_spin(TestCase):
-    """Unit tests for the functions of the 'generic_fns.spin' module."""
+class Spin_base_class:
+    """Base class for the tests of the 'prompt.spin' and 'generic_fns.spin' 
modules.
+
+    This base class also contains shared unit tests.
+    """
 
 
     def setUp(self):




Related Messages


Powered by MHonArc, Updated Sun Nov 18 22:20:11 2007